# 关于拓展教程

本部分内容严格上并不属于`fastapi_amis_admin`开发教程文档范围, 但是通过阅读了解本部分相关内容知识, 将更加有利于`fastapi_amis_admin`的开发.

- [Fastapi](https://fastapi.tiangolo.com/)
- [Amis](https://baidu.gitee.io/amis)
- [SQLModel](https://sqlmodel.tiangolo.com/)
- [SQLAlchemy](https://www.sqlalchemy.org/)
- [Pydantic](https://pydantic-docs.helpmanual.io/)
- [Starlette](https://www.starlette.io/)
- [Jinja2](https://jinja.palletsprojects.com/)
- [Alembic](https://alembic.sqlalchemy.org/en/latest/)
- [Uvicorn](http://www.uvicorn.org/)

